@@ -11,8 +11,16 @@
 /**
  **  Display Help/Info
  **/
-function displayHelp() {
-    PMA_ajaxShowMessage(PMA_messages.strDisplayHelp, 10000);
+function displayHelp () {
+    $('<div />')
+        .append(PMA_messages.strDisplayHelp)
+        .appendTo('#page_content')
+        .dialog({
+            width: 450,
+            height: 'auto',
+            title: PMA_messages.strHelpTitle
+        });
+    return false;
 }
 
 /**
@@ -35,7 +43,7 @@ Array.min = function (array) {
  ** Checks if a string contains only numeric value
  ** @param n: String (to be checked)
  **/
-function isNumeric(n) {
+function isNumeric (n) {
     return !isNaN(parseFloat(n)) && isFinite(n);
 }
 
@@ -43,7 +51,7 @@ function isNumeric(n) {
  ** Checks if an object is empty
  ** @param n: Object (to be checked)
  **/
-function isEmpty(obj) {
+function isEmpty (obj) {
     var name;
     for (name in obj) {
         return false;
@@ -56,16 +64,14 @@ function isEmpty(obj) {
  ** @param val  String Date
  ** @param type Sring  Field type(datetime/timestamp/time/date)
  **/
-function getTimeStamp(val, type) {
-    if (type.toString().search(/datetime/i) != -1 ||
-        type.toString().search(/timestamp/i) != -1
+function getTimeStamp (val, type) {
+    if (type.toString().search(/datetime/i) !== -1 ||
+        type.toString().search(/timestamp/i) !== -1
     ) {
         return $.datepicker.parseDateTime('yy-mm-dd', 'HH:mm:ss', val);
-    }
-    else if (type.toString().search(/time/i) != -1) {
+    } else if (type.toString().search(/time/i) !== -1) {
         return $.datepicker.parseDateTime('yy-mm-dd', 'HH:mm:ss', '1970-01-01 ' + val);
-    }
-    else if (type.toString().search(/date/i) != -1) {
+    } else if (type.toString().search(/date/i) !== -1) {
         return $.datepicker.parseDate('yy-mm-dd', val);
     }
 }
@@ -74,60 +80,47 @@ function getTimeStamp(val, type) {
  ** Classifies the field type into numeric,timeseries or text
  ** @param field: field type (as in database structure)
  **/
-function getType(field) {
-    if (field.toString().search(/int/i) != -1 ||
-        field.toString().search(/decimal/i) != -1 ||
-        field.toString().search(/year/i) != -1
+function getType (field) {
+    if (field.toString().search(/int/i) !== -1 ||
+        field.toString().search(/decimal/i) !== -1 ||
+        field.toString().search(/year/i) !== -1
     ) {
         return 'numeric';
-    } else if (field.toString().search(/time/i) != -1 ||
-        field.toString().search(/date/i) != -1
+    } else if (field.toString().search(/time/i) !== -1 ||
+        field.toString().search(/date/i) !== -1
     ) {
         return 'time';
     } else {
         return 'text';
     }
 }
-/**
- ** Converts a categorical array into numeric array
- ** @param array categorical values array
- **/
-function getCord(arr) {
-    var newCord = [];
-    var original = $.extend(true, [], arr);
-    arr = jQuery.unique(arr).sort();
-    $.each(original, function (index, value) {
-        newCord.push(jQuery.inArray(value, arr));
-    });
-    return [newCord, arr, original];
-}
 
 /**
  ** Scrolls the view to the display section
  **/
-function scrollToChart() {
+function scrollToChart () {
     var x = $('#dataDisplay').offset().top - 100; // 100 provides buffer in viewport
-    $('html,body').animate({scrollTop: x}, 500);
+    $('html,body').animate({ scrollTop: x }, 500);
 }
 
 /**
  * Unbind all event handlers before tearing down a page
  */
 AJAX.registerTeardown('tbl_zoom_plot_jqplot.js', function () {
-    $('#tableid_0').unbind('change');
-    $('#tableid_1').unbind('change');
-    $('#tableid_2').unbind('change');
-    $('#tableid_3').unbind('change');
-    $('#inputFormSubmitId').unbind('click');
-    $('#togglesearchformlink').unbind('click');
-    $("#dataDisplay").find(':input').die('keydown');
-    $('button.button-reset').unbind('click');
-    $('div#resizer').unbind('resizestop');
-    $('div#querychart').unbind('jqplotDataClick');
+    $('#tableid_0').off('change');
+    $('#tableid_1').off('change');
+    $('#tableid_2').off('change');
+    $('#tableid_3').off('change');
+    $('#inputFormSubmitId').off('click');
+    $('#togglesearchformlink').off('click');
+    $(document).off('keydown', '#dataDisplay :input');
+    $('button.button-reset').off('click');
+    $('div#resizer').off('resizestop');
+    $('div#querychart').off('jqplotDataClick');
 });
 
 AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
-    var cursorMode = ($("input[name='mode']:checked").val() == 'edit') ? 'crosshair' : 'pointer';
+    var cursorMode = ($('input[name=\'mode\']:checked').val() === 'edit') ? 'crosshair' : 'pointer';
     var currentChart = null;
     var searchedDataKey = null;
     var xLabel = $('#tableid_0').val();
@@ -142,7 +135,12 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
 
 
     // Get query result
-    var searchedData = jQuery.parseJSON($('#querydata').html());
+    var searchedData;
+    try {
+        searchedData = JSON.parse($('#querydata').html());
+    } catch (err) {
+        searchedData = null;
+    }
 
     /**
      ** Input form submit on field change
@@ -150,20 +148,20 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
 
     // first column choice corresponds to the X axis
     $('#tableid_0').change(function () {
-        //AJAX request for field type, collation, operators, and value field
+        // AJAX request for field type, collation, operators, and value field
         $.post('tbl_zoom_select.php', {
             'ajax_request' : true,
             'change_tbl_info' : true,
+            'server' : PMA_commonParams.get('server'),
             'db' : PMA_commonParams.get('db'),
             'table' : PMA_commonParams.get('table'),
             'field' : $('#tableid_0').val(),
-            'it' : 0,
-            'token' : PMA_commonParams.get('token')
+            'it' : 0
         }, function (data) {
-            $('#tableFieldsId tr:eq(1) td:eq(0)').html(data.field_type);
-            $('#tableFieldsId tr:eq(1) td:eq(1)').html(data.field_collation);
-            $('#tableFieldsId tr:eq(1) td:eq(2)').html(data.field_operators);
-            $('#tableFieldsId tr:eq(1) td:eq(3)').html(data.field_value);
+            $('#tableFieldsId').find('tr:eq(1) td:eq(0)').html(data.field_type);
+            $('#tableFieldsId').find('tr:eq(1) td:eq(1)').html(data.field_collation);
+            $('#tableFieldsId').find('tr:eq(1) td:eq(2)').html(data.field_operators);
+            $('#tableFieldsId').find('tr:eq(1) td:eq(3)').html(data.field_value);
             xLabel = $('#tableid_0').val();
             $('#types_0').val(data.field_type);
             xType = data.field_type;
@@ -174,20 +172,20 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
 
     // second column choice corresponds to the Y axis
     $('#tableid_1').change(function () {
-        //AJAX request for field type, collation, operators, and value field
+        // AJAX request for field type, collation, operators, and value field
         $.post('tbl_zoom_select.php', {
             'ajax_request' : true,
             'change_tbl_info' : true,
+            'server' : PMA_commonParams.get('server'),
             'db' : PMA_commonParams.get('db'),
             'table' : PMA_commonParams.get('table'),
             'field' : $('#tableid_1').val(),
-            'it' : 1,
-            'token' : PMA_commonParams.get('token')
+            'it' : 1
         }, function (data) {
-            $('#tableFieldsId tr:eq(3) td:eq(0)').html(data.field_type);
-            $('#tableFieldsId tr:eq(3) td:eq(1)').html(data.field_collation);
-            $('#tableFieldsId tr:eq(3) td:eq(2)').html(data.field_operators);
-            $('#tableFieldsId tr:eq(3) td:eq(3)').html(data.field_value);
+            $('#tableFieldsId').find('tr:eq(2) td:eq(0)').html(data.field_type);
+            $('#tableFieldsId').find('tr:eq(2) td:eq(1)').html(data.field_collation);
+            $('#tableFieldsId').find('tr:eq(2) td:eq(2)').html(data.field_operators);
+            $('#tableFieldsId').find('tr:eq(2) td:eq(3)').html(data.field_value);
             yLabel = $('#tableid_1').val();
             $('#types_1').val(data.field_type);
             yType = data.field_type;
@@ -197,20 +195,20 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
     });
 
     $('#tableid_2').change(function () {
-        //AJAX request for field type, collation, operators, and value field
+        // AJAX request for field type, collation, operators, and value field
         $.post('tbl_zoom_select.php', {
             'ajax_request' : true,
             'change_tbl_info' : true,
+            'server' : PMA_commonParams.get('server'),
             'db' : PMA_commonParams.get('db'),
             'table' : PMA_commonParams.get('table'),
             'field' : $('#tableid_2').val(),
-            'it' : 2,
-            'token' : PMA_commonParams.get('token')
+            'it' : 2
         }, function (data) {
-            $('#tableFieldsId tr:eq(6) td:eq(0)').html(data.field_type);
-            $('#tableFieldsId tr:eq(6) td:eq(1)').html(data.field_collation);
-            $('#tableFieldsId tr:eq(6) td:eq(2)').html(data.field_operators);
-            $('#tableFieldsId tr:eq(6) td:eq(3)').html(data.field_value);
+            $('#tableFieldsId').find('tr:eq(4) td:eq(0)').html(data.field_type);
+            $('#tableFieldsId').find('tr:eq(4) td:eq(1)').html(data.field_collation);
+            $('#tableFieldsId').find('tr:eq(4) td:eq(2)').html(data.field_operators);
+            $('#tableFieldsId').find('tr:eq(4) td:eq(3)').html(data.field_value);
             $('#types_2').val(data.field_type);
             $('#collations_2').val(data.field_collations);
             addDateTimePicker();
@@ -218,20 +216,20 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
     });
 
     $('#tableid_3').change(function () {
-        //AJAX request for field type, collation, operators, and value field
+        // AJAX request for field type, collation, operators, and value field
         $.post('tbl_zoom_select.php', {
             'ajax_request' : true,
             'change_tbl_info' : true,
+            'server' : PMA_commonParams.get('server'),
             'db' : PMA_commonParams.get('db'),
             'table' : PMA_commonParams.get('table'),
             'field' : $('#tableid_3').val(),
-            'it' : 3,
-            'token' : PMA_commonParams.get('token')
+            'it' : 3
         }, function (data) {
-            $('#tableFieldsId tr:eq(8) td:eq(0)').html(data.field_type);
-            $('#tableFieldsId tr:eq(8) td:eq(1)').html(data.field_collation);
-            $('#tableFieldsId tr:eq(8) td:eq(2)').html(data.field_operators);
-            $('#tableFieldsId tr:eq(8) td:eq(3)').html(data.field_value);
+            $('#tableFieldsId').find('tr:eq(5) td:eq(0)').html(data.field_type);
+            $('#tableFieldsId').find('tr:eq(5) td:eq(1)').html(data.field_collation);
+            $('#tableFieldsId').find('tr:eq(5) td:eq(2)').html(data.field_operators);
+            $('#tableFieldsId').find('tr:eq(5) td:eq(3)').html(data.field_value);
             $('#types_3').val(data.field_type);
             $('#collations_3').val(data.field_collations);
             addDateTimePicker();
@@ -244,7 +242,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
     $('#inputFormSubmitId').click(function () {
         if ($('#tableid_0').get(0).selectedIndex === 0 || $('#tableid_1').get(0).selectedIndex === 0) {
             PMA_ajaxShowMessage(PMA_messages.strInputNull);
-        } else if (xLabel == yLabel) {
+        } else if (xLabel === yLabel) {
             PMA_ajaxShowMessage(PMA_messages.strSameInputs);
         }
     });
@@ -263,7 +261,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
         .bind('click', function () {
             var $link = $(this);
             $('#zoom_search_form').slideToggle();
-            if ($link.text() == PMA_messages.strHideSearchCriteria) {
+            if ($link.text() === PMA_messages.strHideSearchCriteria) {
                 $link.text(PMA_messages.strShowSearchCriteria);
             } else {
                 $link.text(PMA_messages.strHideSearchCriteria);
@@ -280,8 +278,8 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
      * Handle saving of a row in the editor
      */
     buttonOptions[PMA_messages.strSave] = function () {
-        //Find changed values by comparing form values with selectedRow Object
-        var newValues = {};//Stores the values changed from original
+        // Find changed values by comparing form values with selectedRow Object
+        var newValues = {};// Stores the values changed from original
         var sqlTypes = {};
         var it = 0;
         var xChange = false;
@@ -294,15 +292,15 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
             var oldVal = selectedRow[key];
             var newVal = ($('#edit_fields_null_id_' + it).prop('checked')) ? null : $('#edit_fieldID_' + it).val();
             if (newVal instanceof Array) { // when the column is of type SET
-                newVal =  $('#edit_fieldID_' + it).map(tempGetVal).get().join(",");
+                newVal =  $('#edit_fieldID_' + it).map(tempGetVal).get().join(',');
             }
-            if (oldVal != newVal) {
+            if (oldVal !== newVal) {
                 selectedRow[key] = newVal;
                 newValues[key] = newVal;
-                if (key == xLabel) {
+                if (key === xLabel) {
                     xChange = true;
                     searchedData[searchedDataKey][xLabel] = newVal;
-                } else if (key == yLabel) {
+                } else if (key === yLabel) {
                     yChange = true;
                     searchedData[searchedDataKey][yLabel] = newVal;
                 }
@@ -314,18 +312,18 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
                 sqlTypes[key] = null;
             }
             it++;
-        } //End data update
+        } // End data update
 
-        //Update the chart series and replot
+        // Update the chart series and replot
         if (xChange || yChange) {
-            //Logic similar to plot generation, replot only if xAxis changes or yAxis changes.
-            //Code includes a lot of checks so as to replot only when necessary
+            // Logic similar to plot generation, replot only if xAxis changes or yAxis changes.
+            // Code includes a lot of checks so as to replot only when necessary
             if (xChange) {
                 xCord[searchedDataKey] = selectedRow[xLabel];
                 // [searchedDataKey][0] contains the x value
-                if (xType == 'numeric') {
+                if (xType === 'numeric') {
                     series[0][searchedDataKey][0] = selectedRow[xLabel];
-                } else if (xType == 'time') {
+                } else if (xType === 'time') {
                     series[0][searchedDataKey][0] =
                         getTimeStamp(selectedRow[xLabel], $('#types_0').val());
                 } else {
@@ -335,14 +333,13 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
                 currentChart.series[0].data = series[0];
                 // TODO: axis changing
                 currentChart.replot();
-
             }
             if (yChange) {
                 yCord[searchedDataKey] = selectedRow[yLabel];
                 // [searchedDataKey][1] contains the y value
-                if (yType == 'numeric') {
+                if (yType === 'numeric') {
                     series[0][searchedDataKey][1] = selectedRow[yLabel];
-                } else if (yType == 'time') {
+                } else if (yType === 'time') {
                     series[0][searchedDataKey][1] =
                         getTimeStamp(selectedRow[yLabel], $('#types_1').val());
                 } else {
@@ -353,9 +350,9 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
                 // TODO: axis changing
                 currentChart.replot();
             }
-        } //End plot update
+        } // End plot update
 
-        //Generate SQL query for update
+        // Generate SQL query for update
         if (!isEmpty(newValues)) {
             var sql_query = 'UPDATE `' + PMA_commonParams.get('table') + '` SET ';
             for (key in newValues) {
@@ -368,19 +365,19 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
 
                 // empty
                 } else if ($.trim(value) === '') {
-                    sql_query += "'', ";
+                    sql_query += '\'\', ';
 
                 // other
                 } else {
                     // type explicitly identified
                     if (sqlTypes[key] !== null) {
-                        if (sqlTypes[key] == 'bit') {
-                            sql_query += "b'" + value + "', ";
+                        if (sqlTypes[key] === 'bit') {
+                            sql_query += 'b\'' + value + '\', ';
                         }
                     // type not explicitly identified
                     } else {
                         if (!isNumeric(value)) {
-                            sql_query += "'" + value + "', ";
+                            sql_query += '\'' + value + '\', ';
                         } else {
                             sql_query += value + ', ';
                         }
@@ -391,28 +388,28 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
             sql_query = sql_query.substring(0, sql_query.length - 2);
             sql_query += ' WHERE ' + PMA_urldecode(searchedData[searchedDataKey].where_clause);
 
-            //Post SQL query to sql.php
+            // Post SQL query to sql.php
             $.post('sql.php', {
-                    'token' : PMA_commonParams.get('token'),
-                    'db' : PMA_commonParams.get('db'),
-                    'ajax_request' : true,
-                    'sql_query' : sql_query,
-                    'inline_edit' : false
-                }, function (data) {
-                    if (typeof data !== 'undefined' && data.success === true) {
-                        $('#sqlqueryresults').html(data.sql_query);
-                        $("#sqlqueryresults").trigger('appendAnchor');
-                    } else {
-                        PMA_ajaxShowMessage(data.error, false);
-                    }
-                }); //End $.post
-        }//End database update
-        $("#dataDisplay").dialog('close');
+                'server' : PMA_commonParams.get('server'),
+                'db' : PMA_commonParams.get('db'),
+                'ajax_request' : true,
+                'sql_query' : sql_query,
+                'inline_edit' : false
+            }, function (data) {
+                if (typeof data !== 'undefined' && data.success === true) {
+                    $('#sqlqueryresultsouter').html(data.sql_query);
+                    PMA_highlightSQL($('#sqlqueryresultsouter'));
+                } else {
+                    PMA_ajaxShowMessage(data.error, false);
+                }
+            }); // End $.post
+        }// End database update
+        $('#dataDisplay').dialog('close');
     };
     buttonOptions[PMA_messages.strCancel] = function () {
         $(this).dialog('close');
     };
-    $("#dataDisplay").dialog({
+    $('#dataDisplay').dialog({
         autoOpen: false,
         title: PMA_messages.strDataPointContent,
         modal: true,
@@ -427,7 +424,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
      * in the dialog. Used to submit the Ajax
      * request when the ENTER key is pressed.
      */
-    $("#dataDisplay").find(':input').live('keydown', function (e) {
+    $(document).on('keydown', '#dataDisplay :input', function (e) {
         if (e.which === 13) { // 13 is the ENTER key
             e.preventDefault();
             if (typeof buttonOptions[PMA_messages.strSave] === 'function') {
@@ -443,17 +440,18 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
 
     if (searchedData !== null) {
         $('#zoom_search_form')
-         .slideToggle()
-         .hide();
+            .slideToggle()
+            .hide();
         $('#togglesearchformlink')
-         .text(PMA_messages.strShowSearchCriteria);
+            .text(PMA_messages.strShowSearchCriteria);
         $('#togglesearchformdiv').show();
         var selectedRow;
         var colorCodes = ['#FF0000', '#00FFFF', '#0000FF', '#0000A0', '#FF0080', '#800080', '#FFFF00', '#00FF00', '#FF00FF'];
         var series = [];
         var xCord = [];
         var yCord = [];
-        var tempX, tempY;
+        var tempX;
+        var tempY;
         var it = 0;
         var xMax; // xAxis extreme max
         var xMin; // xAxis extreme min
@@ -509,17 +507,17 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
         // could have multiple series but we'll have just one
         series[0] = [];
 
-        if (xType == 'time') {
+        if (xType === 'time') {
             var originalXType = $('#types_0').val();
-            if (originalXType == 'date') {
+            if (originalXType === 'date') {
                 format = '%Y-%m-%d';
             }
             // TODO: does not seem to work
-            //else if (originalXType == 'time') {
-              //  format = '%H:%M';
-            //} else {
+            // else if (originalXType === 'time') {
+            //  format = '%H:%M';
+            // } else {
             //    format = '%Y-%m-%d %H:%M';
-            //}
+            // }
             $.extend(options.axes.xaxis, {
                 renderer: $.jqplot.DateAxisRenderer,
                 tickOptions: {
@@ -527,9 +525,9 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
                 }
             });
         }
-        if (yType == 'time') {
+        if (yType === 'time') {
             var originalYType = $('#types_1').val();
-            if (originalYType == 'date') {
+            if (originalYType === 'date') {
                 format = '%Y-%m-%d';
             }
             $.extend(options.axes.yaxis, {
@@ -541,16 +539,16 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
         }
 
         $.each(searchedData, function (key, value) {
-            if (xType == 'numeric') {
+            if (xType === 'numeric') {
                 xVal = parseFloat(value[xLabel]);
             }
-            if (xType == 'time') {
+            if (xType === 'time') {
                 xVal = getTimeStamp(value[xLabel], originalXType);
             }
-            if (yType == 'numeric') {
+            if (yType === 'numeric') {
                 yVal = parseFloat(value[yLabel]);
             }
-            if (yType == 'time') {
+            if (yType === 'time') {
                 yVal = getTimeStamp(value[yLabel], originalYType);
             }
             series[0].push([
@@ -558,7 +556,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
                 yVal,
                 // extra Y values
                 value[dataLabel], // for highlighter
-                                  // (may set an undefined value)
+                // (may set an undefined value)
                 value.where_clause, // for click on point
                 key               // key from searchedData
             ]);
@@ -580,7 +578,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
             // make room so that the handle will still appear
             $('div#querychart').height($('div#resizer').height() * 0.96);
             $('div#querychart').width($('div#resizer').width() * 0.96);
-            currentChart.replot({resetAxes: true});
+            currentChart.replot({ resetAxes: true });
         });
 
         $('div#querychart').bind('jqplotDataClick',
@@ -590,10 +588,10 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
                 var post_params = {
                     'ajax_request' : true,
                     'get_data_row' : true,
+                    'server' : PMA_commonParams.get('server'),
                     'db' : PMA_commonParams.get('db'),
                     'table' : PMA_commonParams.get('table'),
-                    'where_clause' : data[3],
-                    'token' : PMA_commonParams.get('token')
+                    'where_clause' : data[3]
                 };
 
                 $.post('tbl_zoom_select.php', post_params, function (data) {
@@ -601,8 +599,8 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
                     // now fill the displayResultForm with row values
                     var key;
                     for (key in data.row_info) {
-                        $field = $('#edit_fieldID_' + field_id);
-                        $field_null = $('#edit_fields_null_id_' + field_id);
+                        var $field = $('#edit_fieldID_' + field_id);
+                        var $field_null = $('#edit_fields_null_id_' + field_id);
                         if (data.row_info[key] === null) {
                             $field_null.prop('checked', true);
                             $field.val('');
@@ -616,12 +614,15 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
                         }
                         field_id++;
                     }
-                    selectedRow = {};
                     selectedRow = data.row_info;
                 });
 
-                $("#dataDisplay").dialog("open");
+                $('#dataDisplay').dialog('open');
             }
         );
     }
+
+    $('#help_dialog').click(function () {
+        displayHelp();
+    });
 });
