@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+use PhpMyAdmin\OutputBuffering;
+use PhpMyAdmin\ThemeManager;
 
 /**
  *
@@ -13,13 +15,14 @@
 define('PMA_MINIMUM_COMMON', true);
 require_once 'libraries/common.inc.php';
 
-// MSIE 6 (at least some unpatched versions) has problems loading CSS
-// when zlib_compression is on
-if (PMA_USR_BROWSER_AGENT == 'IE' && PMA_USR_BROWSER_VER == '6'
-    && (ini_get('zlib.output_compression'))
-) {
-    @ini_set('zlib.output_compression', 'Off');
-}
+
+$buffer = OutputBuffering::getInstance();
+$buffer->start();
+register_shutdown_function(
+    function () {
+        echo OutputBuffering::getInstance()->getContents();
+    }
+);
 
 // Send correct type:
 header('Content-Type: text/css; charset=UTF-8');
@@ -28,5 +31,4 @@ header('Content-Type: text/css; charset=UTF-8');
 // file is reloaded when config changes
 header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 3600) . ' GMT');
 
-$_SESSION['PMA_Theme_Manager']->printCss();
-?>
+ThemeManager::getInstance()->printCss();
